<?php

namespace Drupal\language_combination\Plugin\Field\FieldFormatter;

use Drupal\Component\Utility\Html;
use Drupal\Core\Field\FieldItemListInterface;
use Drupal\Core\Field\FormatterBase;

/**
 * Plugin implementation of the 'language_combination_table' formatter.
 *
 * @FieldFormatter(
 *   id = "language_combination_table",
 *   label = @Translation("Table"),
 *   field_types = {
 *     "language_combination",
 *   }
 * )
 */
class LanguageCombinationTableFormatter extends FormatterBase {

  /**
   * {@inheritdoc}
   */
  public function viewElements(FieldItemListInterface $items, $langcode) {
    $rows = [];

    $installed_languages = \Drupal::languageManager()->getLanguages();

    foreach ($items as $item) {
      $from = $installed_languages[$item->language_from]->getName();
      $to = $installed_languages[$item->language_to]->getName();
      $row[] = [
        'data' => $from,
        'class' => ['from-language', Html::getClass('language-' . $from)],
      ];

      $row[] = [
        'data' => $to,
        'class' => ['to-language', Html::getClass('language-' . $to)],
      ];

      $rows[] = [
        'data' => $row,
        'class' => [Html::getClass($from . '-' . $to)],
      ];
      $row = NULL;
    }

    return [
      '#theme' => 'table',
      '#header' => [t('From'), t('To')],
      '#rows' => $rows,
    ];

  }

}
